﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;
using MinorShift._Library;
using System.IO;

namespace MinorShift.Emuera
{
	static class Program
	{
		/*
		コードの開始地点。
		ここでMainWindowを作り、
		MainWindowがProcessを作り、
		ProcessがGameBase・ConstantData・Variableを作る。
		
		
		*.ERBの読み込み、実行、その他の処理をProcessが、
		入出力をMainWindowが、
		定数の保存をConstantDataが、
		変数の管理をVariableが行う。
		 
		と言う予定だったが改変するうちに境界が曖昧になってしまった。
		 
		後にEmueraConsoleを追加し、それに入出力を担当させることに。

		*/
		/// <summary>
		/// アプリケーションのメイン エントリ ポイントです。
		/// </summary>
		[STAThread]
		static void Main(string[] args)
		{
			
			Application.EnableVisualStyles();
			Application.SetCompatibleTextRenderingDefault(false);
			Config.Instance.LoadConfig();
			//二重起動の禁止かつ二重起動
			if ((!Config.Instance.AllowMultipleInstances) && (Sys.PrevInstance()))
			{

				MessageBox.Show("多重起動を許可する場合、emuera.configを書き換えて下さい", "既に起動しています");
				return;
			}
			if (!Directory.Exists(ExeDir + "csv"))
			{
				MessageBox.Show("csvフォルダが見つかりません", "フォルダなし");
				return;
			}
			if (!Directory.Exists(ExeDir + "erb"))
			{
				MessageBox.Show("erbフォルダが見つかりません", "フォルダなし");
				return;
			}

            if (args.Length > 0)
            {
                AnalysisFiles = new List<string>();
                for (int i = 0; i < args.Length; i++)
                {
                    if (!File.Exists(args[i]) && !Directory.Exists(args[i]))
                    {
                        MessageBox.Show("与えられたファイル・フォルダは存在しません");
                        return;
                    }
                    if ((File.GetAttributes(args[i]) & FileAttributes.Directory) == FileAttributes.Directory)
                    {
                        List<KeyValuePair<string, string>> fnames = Config.Instance.GetFiles(args[i] + "\\", "*.ERB");
                        for (int j = 0; j < fnames.Count; j++)
                        {
                            AnalysisFiles.Add(fnames[j].Value);
                        }
                    }
                    else
                    {
                        if (Path.GetExtension(args[i]).ToUpper() != ".ERB")
                        {
                            MessageBox.Show("ドロップ可能なファイルはERBファイルのみです");
                            return;
                        }
                        AnalysisFiles.Add(args[i]);
                    }
                }
                AnalysisMode = true;
            }
			while (true)
			{
				Application.Run(new MainWindow());
                if (!Reboot)
					break;
				Reboot = false;
				Config.Instance.LoadConfig();
			}
		}

		public static string ExeDir
		{
			get
			{
#if DEBUG
				return Sys.ExeDir;
#else
				return Sys.ExeDir;
#endif
			}
		}
		public static bool Reboot = false;
        public static int ClientX = 0;
        public static int ClientY = 0;
        public static FormWindowState state = FormWindowState.Normal;
        public static bool AnalysisMode = false;
        public static List<string> AnalysisFiles = null;
	}
}